@@ -4,7 +4,7 @@ use Net::Rendezvous;
 
 my $res = new Net::Rendezvous($ARGV[0]);
 print $res->domain($ARGV[1]), "\n";
-print $res->discover;
+$res->discover;
 
 foreach $entry ( $res->entries ) {
 	printf "%s %s:%s\n",  $entry->name, $entry->hostname, $entry->port;
